import { BaseTCFUserDecision } from './interfaces.decisions';
/** A user's consent decision on all TCF options */
export interface TCFUserDecisions {
    /** A user's consent decision on TCF purposes */
    purposes?: TCFUserDecisionOnPurpose[];
    /** A user's consent decision on TCF special features */
    specialFeatures?: TCFUserDecisionOnSpecialFeature[];
    /** A user's consent decision on TCF vendors */
    vendors?: TCFUserDecisionOnVendor[];
    /** A user's consent decision on Google Additional Consent Mode vendors */
    acmVendors?: ACMUserDecisionOnVendor[];
}
/** A user's consent decision for a single purpose */
export interface TCFUserDecisionOnPurpose extends BaseTCFUserDecision {
    /** Indicates if the user gave legitimate interest consent (true) or denied consent (false) */
    legitimateInterestConsent: boolean;
}
/** A user's consent decision for a single special feature */
export type TCFUserDecisionOnSpecialFeature = BaseTCFUserDecision;
/** A user's consent decision for a single vendor */
export interface TCFUserDecisionOnVendor extends BaseTCFUserDecision {
    /** Indicates if the user gave legitimate interest consent (true) or denied consent (false) */
    legitimateInterestConsent: boolean;
}
export type ACMUserDecisionOnVendor = BaseTCFUserDecision;
